==> vpn-user-portal-3.6.4.tgz: vpn-user-portal/locale/sk-SK.php <==
<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

return [
    '#Active (Max #Available) Connections' => '#Aktívnych (Max #dostupných) pripojení',
    '#Connections in 5 minute intervals' => '#Pripojení v 5-minútových intervaloch',
    '#Unique Guest Users' => '#Jedinečných externých používateľov',
    '#Unique Users' => '#Jedinečných používateľov',
    '#Unique users and max #connections per day' => '#Jedinečných používateľov a max. #pripojení za deň',
    'ACL Permission List' => 'ACL zoznam oprávnení',
    'Account' => 'Účet',
    'Active' => 'Aktívny',
    'Active Configurations' => 'Aktívne konfigurácie',
    'Aggregated' => 'Agregované',
    'All' => 'Všetko',
    'An application attempts to establish a VPN connection.' => 'Aplikácia sa pokúša vytvoriť VPN pripojenie.',
    'An error occurred.' => 'Vyskytla sa chyba.',
    'Application Usage' => 'Použitie aplikácie',
    'Approve' => 'Schváliť',
    'Approve Application' => 'Schváliť aplikáciu',
    'Authentication Data' => 'Autentizačné dáta',
    'Authorized Applications' => 'Autorizované aplikácie',
    'Authorized On' => 'Schválené dňa',
    'Available Profiles' => 'Dostupné profily',
    'Block LAN' => 'Blokovať LAN',
    'CA' => 'Certifikačná Autorita',
    'CPU Usage:' => 'Využitie CPU:',
    'Change Password' => 'Zmeniť heslo',
    'Configurations' => 'Konfigurácie',
    'Confirm' => 'Potvrdiť',
    'Connected' => 'Pripojený',
    'Connections' => 'Pripojenia',
    'Created On' => 'Vytvorené dňa',
    'Current Password' => 'Aktuálne heslo',
    'Current Password not correct!' => 'Aktuálne heslo nie je správne!',
    'Currently there are no clients connected to this profile.' => 'Momentálne nie sú k tomuto profilu pripojení žiadni klienti.',
    'DNS Search Domain(s)' => 'DNS vyhľadávacie domény',
    'DNS Server(s)' => 'DNS Servery',
    'Danger Zone' => 'Nebezpečná zóna',
    'Date/Time' => 'Dátum/Čas',
    'Default Gateway' => 'Predvolená brána',
    'Delete' => 'Zmazať',
    'Delete Account' => 'Zmazať účet',
    'Delete Account Data' => 'Zmazať dáta účtu',
    'Disable Account' => 'Zakázať účet',
    'Disabled' => 'Zakázaný',
    'Disconnected' => 'Odpojený',
    'Distribution of unique users over the VPN applications.' => 'Rozdelenie jedinečných používateľov medzi VPN aplikáciami.',
    'Download' => 'Stiahnuť',
    'Downloading VPN configurations is not allowed. Please use a VPN application.' => 'Stiahnutie VPN konfigurácií nie je povolené. Použite prosím VPN aplikáciu.',
    'Enable Account' => 'Povoliť účet',
    'Error' => 'Chyba',
    'Excluded Route(s)' => 'Vylúčené trasy',
    'Expires On' => 'Platný do',
    'Export (CSV)' => 'Exportovať (CSV)',
    'Find the user identifier that used an IPv4 or IPv6 address at a particular point in time.' => 'Nájsť identifikátor používateľa, ktorý používal IPv4 alebo IPv6 adresu v konkrétnom čase.',
    'Fingerprint' => 'Odtlačok prstov',
    'Here you can change the password for your account.' => 'Tu môžete zmeniť heslo k Vášmu účtu.',
    'Home' => 'Domov',
    'Hostname' => 'Hostname',
    'IP Address' => 'IP adresa',
    'IPs' => 'IP',
    'IPv4 Prefix' => 'IPv4 prefix',
    'IPv6 Prefix' => 'IPv6 prefix',
    'Import or copy/paste this configuration to your WireGuard application.' => 'Importovať alebo skopírovať/vložiť túto konfiguráciu do Vašej aplikácie WireGuard.',
    'Info' => 'Informácie',
    'Issues' => 'Problémy',
    'Live' => 'Živé',
    'Log' => 'Záznam',
    //'MTU' => '',
    'Max #Connections' => 'Max. #pripojení',
    'More' => 'Viac',
    'N/A' => 'Nie je dostupné',
    'Name' => 'Meno',
    'New Configuration' => 'Nová konfigurácia',
    'New Password' => 'Nové heslo',
    'New Password (confirm)' => 'Nové heslo (potvrdenie)',
    'New Password and New Password (confirm) MUST match!' => 'Nové heslo a Nové heslo (potvrdenie) sa MUSIA zhodovať!',
    'No Permission(s)' => 'Žiadne oprávnenia',
    'No VPN profiles are available for your account.' => 'Pre Váš účet nie sú dostupné žiadne VPN profily.',
    'Node URL' => 'URL uzlu',
    'Node(s)' => 'Uzly',
    'OAuth' => 'OAuth',
    'Obtain a new VPN configuration file for use in your VPN client.' => 'Získať nový konfiguračný súbor pre použitie vo Vašom VPN klientovi.',
    'Offered Ports' => 'Dostupné porty',
    'Offline' => 'Nepripojený',
    'Online' => 'Pripojený',
    'Only approve this when you are trying to establish a VPN connection with this application!' => 'Schválte toto len v prípade, že sa snažíte vytvoriť VPN pripojenie s touto aplikáciou!',
    'OpenVPN' => 'OpenVPN',
    //'OpenVPN (Prefer TCP)' => '',
    //'OpenVPN (Prefer UDP)' => '',
    'OpenVPN Server Log' => 'Záznam OpenVPN servera',
    'Password' => 'Heslo',
    'Permissions' => 'Oprávnenia',
    'Please sign in with your username and password.' => 'Prosím prihláste sa so svojím používateľským menom a heslom.',
    'Port' => 'Port',
    'Ports' => 'Porty',
    'Preferred Protocol' => 'Preferovaný protokol',
    'Profile' => 'Profil',
    //'Profile ID' => '',
    'Profile Usage' => 'Využitie profilu',
    'Profile(s)' => 'Profily',
    'Public Key' => 'Verejný kľúč',
    //'Refresh' => '',
    'Results' => 'Výsledky',
    'Revoke' => 'Odobrať',
    'Route(s)' => 'Trasy',
    'Search' => 'Hľadať',
    'Select a profile and choose a name, e.g. "Phone".' => 'Vyberte profil a vyberte meno, napr. "Telefón".',
    'Server' => 'Server',
    'Sign In' => 'Prihlásiť sa',
    'Sign Out' => 'Odhlásiť sa',
    //'Sorted by "Authorized On", most recent authorization first.' => '',
    'Stats' => 'Štatistiky',
    'The <em>Date/Time</em> MUST be in UTC.' => '<em>Dátum/Čas</em> MUSÍ byť v UTC.',
    'The <em>Date/Time</em> field accepts dates of the format <code>Y-m-d H:i:s</code>, e.g. <code>2019-01-01 08:00:00</code>.' => 'Pole <em>Dátum/Čas</em> prijíma dátumy vo formáte <code>Y-m-d H:i:s</code>, napr. <code>2019-01-01 08:00:00</code>.',
    'The credentials you provided were not correct.' => 'Poskytnuté prihlasovacie údaje nie sú správne.',
    'The list of applications you authorized to create a VPN connection.' => 'Zoznam aplikácií, ktorým ste umožnili vytvárať VPN pripojenia.',
    'The maximum number of simultaneously connected VPN clients at a particular moment in time over the last week' => 'Maximálny počet súčasne pripojených VPN klientov v konkrétny okamih počas posledného týždňa',
    'The most recent VPN connections with this account.' => 'Najnovšie VPN pripojenia s týmto účtom.',
    'The number of currently connected VPN clients, and the maximum possible number of connected VPN clients based on available IP-space for this profile.' => 'Počet aktuálne pripojených VPN klientov a maximálny možný počet pripojených VPN klientov na základe dostupného IP priestoru pre tento profil.',
    'The number of unique guest users connecting to the VPN service in the last week' => 'Počet jedinečných externých používateľov pripojených k VPN službe počas posledného týždňa',
    'The number of unique users connecting to the VPN service in the last week' => 'Počet jedinečných používateľov pripojených k VPN službe počas posledného týždňa',
    'The table below shows the per profile VPN usage over the last week.' => 'Tabuľka nižšie zobrazuje využitie VPN profilov za posledný týždeň.',
    'There are no results matching your criteria.' => 'Neexistujú žiadne výsledky zodpovedajúce vašim kritériám.',
    'This server uses an external authentication source. Deleting the account data will not prevent the user from authenticating (again)!' => 'Tento server používa externý autentizačný zdroj. Odstránenie údajov o účte nezabráni používateľovi v overení (znovu)!',
    'This user does not have any active configurations.' => 'Tento používateľ nemá žiadne aktívne konfigurácie.',
    'This user does not have any connections.' => 'Tento používateľ nemá žiadne pripojenia.',
    'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'Ak chcete zabrániť zákerným aplikáciám vo vašom mene tajne vytvárať VPN pripojenia, musíte najskôr túto aplikáciu explicitne schváliť.',
    'Use the WireGuard app on your mobile device to scan this QR code.' => 'Použite aplikáciu WireGuard na svojom mobilnom zariadení na oskenovanie tohto QR kódu.',
    'User ID' => 'Používateľské ID',
    'Username' => 'Používateľské meno',
    'Users' => 'Používatelia',
    'VPN Portal' => 'VPN portál',
    'Version' => 'Verzia',
    'Welcome to this VPN service!' => 'Vitajte v tejto VPN službe!',
    'Why is this necessary?' => 'Prečo je toto nevyhnutné?',
    'WireGuard' => 'WireGuard',
    //'WireGuard (TCP)' => '',
    //'WireGuard (UDP)' => '',
    'WireGuard Configuration' => 'WireGuard konfigurácia',
    'You can download the detailed VPN usage statistics below.' => 'Podrobné štatistiky používania VPN si môžete stiahnuť nižšie.',
    'You cannot manage your own user account.' => 'Nemôžete spravovať svoj vlastný používateľský účet.',
    'You have reached the maximum number of allowed active VPN configurations. Delete some first.' => 'Dosiahli ste maximálny počet povolených aktívnych VPN konfigurácií. Najskôr niektoré zmažte.',
    'Your account does not have access to any VPN profile.' => 'Váš účet nemá prístup k žiadnemu VPN profilu.',
    'Your new configuration will expire on %expiryDate%. Come back here to obtain a new configuration after expiry!' => 'Vaša nová konfigurácia vyprší %expiryDate%. Po vypršaní príďte sem pre získanie novej konfigurácie!',
];

==> vpn-user-portal-3.7.2.tgz: vpn-user-portal/locale/sk-SK.php <==
<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

return [
    '#Active (Max #Available) Connections' => '#Aktívnych (Max #dostupných) pripojení',
    '#Connections in 5 minute intervals' => '#Pripojení v 5-minútových intervaloch',
    '#Unique Guest Users' => '#Jedinečných externých používateľov',
    '#Unique Users' => '#Jedinečných používateľov',
    '#Unique users and max #connections per day' => '#Jedinečných používateľov a max. #pripojení za deň',
    'ACL Permission List' => 'ACL zoznam oprávnení',
    'Account' => 'Účet',
    'Active' => 'Aktívny',
    'Active Configurations' => 'Aktívne konfigurácie',
    'Aggregated' => 'Agregované',
    'All' => 'Všetko',
    'An application attempts to establish a VPN connection.' => 'Aplikácia sa pokúša vytvoriť VPN pripojenie.',
    'An error occurred.' => 'Vyskytla sa chyba.',
    'Application Usage' => 'Použitie aplikácie',
    'Approve' => 'Schváliť',
    'Approve Application' => 'Schváliť aplikáciu',
    'Authentication Data' => 'Autentizačné dáta',
    'Authorized Applications' => 'Autorizované aplikácie',
    'Authorized On' => 'Schválené dňa',
    'Available Profiles' => 'Dostupné profily',
    'Block LAN' => 'Blokovať LAN',
    'CA' => 'Certifikačná Autorita',
    'CPU Usage:' => 'Využitie CPU:',
    'Change Password' => 'Zmeniť heslo',
    'Configurations' => 'Konfigurácie',
    'Confirm' => 'Potvrdiť',
    'Connected' => 'Pripojený',
    'Connections' => 'Pripojenia',
    'Created On' => 'Vytvorené dňa',
    'Current Password' => 'Aktuálne heslo',
    'Current Password not correct!' => 'Aktuálne heslo nie je správne!',
    'Currently there are no clients connected to this profile.' => 'Momentálne nie sú k tomuto profilu pripojení žiadni klienti.',
    'DNS Search Domain(s)' => 'DNS vyhľadávacie domény',
    'DNS Server(s)' => 'DNS Servery',
    'Danger Zone' => 'Nebezpečná zóna',
    //'Database' => '',
    'Date/Time' => 'Dátum/Čas',
    'Default Gateway' => 'Predvolená brána',
    'Delete' => 'Zmazať',
    'Delete Account' => 'Zmazať účet',
    'Delete Account Data' => 'Zmazať dáta účtu',
    'Disable Account' => 'Zakázať účet',
    'Disabled' => 'Zakázaný',
    'Disconnected' => 'Odpojený',
    'Distribution of unique users over the VPN applications.' => 'Rozdelenie jedinečných používateľov medzi VPN aplikáciami.',
    'Download' => 'Stiahnuť',
    'Downloading VPN configurations is not allowed. Please use a VPN application.' => 'Stiahnutie VPN konfigurácií nie je povolené. Použite prosím VPN aplikáciu.',
    //'Driver' => '',
    'Enable Account' => 'Povoliť účet',
    'Error' => 'Chyba',
    'Excluded Route(s)' => 'Vylúčené trasy',
    'Expires On' => 'Platný do',
    'Export (CSV)' => 'Exportovať (CSV)',
    'Find the user identifier that used an IPv4 or IPv6 address at a particular point in time.' => 'Nájsť identifikátor používateľa, ktorý používal IPv4 alebo IPv6 adresu v konkrétnom čase.',
    'Fingerprint' => 'Odtlačok prstov',
    'Here you can change the password for your account.' => 'Tu môžete zmeniť heslo k Vášmu účtu.',
    'Home' => 'Domov',
    'Hostname' => 'Hostname',
    'IP Address' => 'IP adresa',
    'IPs' => 'IP',
    'IPv4 Prefix' => 'IPv4 prefix',
    'IPv6 Prefix' => 'IPv6 prefix',
    'Import or copy/paste this configuration to your WireGuard application.' => 'Importovať alebo skopírovať/vložiť túto konfiguráciu do Vašej aplikácie WireGuard.',
    'Info' => 'Informácie',
    'Issues' => 'Problémy',
    //'Last Used' => '',
    'Live' => 'Živé',
    'Log' => 'Záznam',
    //'MTU' => '',
    'Max #Connections' => 'Max. #pripojení',
    'More' => 'Viac',
    'N/A' => 'Nie je dostupné',
    'Name' => 'Meno',
    'New Configuration' => 'Nová konfigurácia',
    'New Password' => 'Nové heslo',
    'New Password (confirm)' => 'Nové heslo (potvrdenie)',
    'New Password and New Password (confirm) MUST match!' => 'Nové heslo a Nové heslo (potvrdenie) sa MUSIA zhodovať!',
    'No Permission(s)' => 'Žiadne oprávnenia',
    'No VPN profiles are available for your account.' => 'Pre Váš účet nie sú dostupné žiadne VPN profily.',
    'Node URL' => 'URL uzlu',
    'Node(s)' => 'Uzly',
    'OAuth' => 'OAuth',
    'Obtain a new VPN configuration file for use in your VPN client.' => 'Získať nový konfiguračný súbor pre použitie vo Vašom VPN klientovi.',
    'Offered Ports' => 'Dostupné porty',
    'Offline' => 'Nepripojený',
    'Online' => 'Pripojený',
    'Only approve this when you are trying to establish a VPN connection with this application!' => 'Schválte toto len v prípade, že sa snažíte vytvoriť VPN pripojenie s touto aplikáciou!',
    'OpenVPN' => 'OpenVPN',
    //'OpenVPN (Prefer TCP)' => '',
    //'OpenVPN (Prefer UDP)' => '',
    'OpenVPN Server Log' => 'Záznam OpenVPN servera',
    'Password' => 'Heslo',
    'Permissions' => 'Oprávnenia',
    'Please sign in with your username and password.' => 'Prosím prihláste sa so svojím používateľským menom a heslom.',
    'Port' => 'Port',
    'Ports' => 'Porty',
    'Preferred Protocol' => 'Preferovaný protokol',
    'Profile' => 'Profil',
    //'Profile ID' => '',
    'Profile Usage' => 'Využitie profilu',
    'Profile(s)' => 'Profily',
    //'Proxy URL' => '',
    'Public Key' => 'Verejný kľúč',
    //'Refresh' => '',
    'Results' => 'Výsledky',
    'Revoke' => 'Odobrať',
    'Route(s)' => 'Trasy',
    'Search' => 'Hľadať',
    'Select a profile and choose a name, e.g. "Phone".' => 'Vyberte profil a vyberte meno, napr. "Telefón".',
    'Server' => 'Server',
    'Sign In' => 'Prihlásiť sa',
    'Sign Out' => 'Odhlásiť sa',
    //'Sorted by "Last Used", most recently used first.' => '',
    'Stats' => 'Štatistiky',
    'The <em>Date/Time</em> MUST be in UTC.' => '<em>Dátum/Čas</em> MUSÍ byť v UTC.',
    'The <em>Date/Time</em> field accepts dates of the format <code>Y-m-d H:i:s</code>, e.g. <code>2019-01-01 08:00:00</code>.' => 'Pole <em>Dátum/Čas</em> prijíma dátumy vo formáte <code>Y-m-d H:i:s</code>, napr. <code>2019-01-01 08:00:00</code>.',
    'The credentials you provided were not correct.' => 'Poskytnuté prihlasovacie údaje nie sú správne.',
    'The list of applications you authorized to create a VPN connection.' => 'Zoznam aplikácií, ktorým ste umožnili vytvárať VPN pripojenia.',
    'The maximum number of simultaneously connected VPN clients at a particular moment in time over the last week' => 'Maximálny počet súčasne pripojených VPN klientov v konkrétny okamih počas posledného týždňa',
    'The most recent VPN connections with this account.' => 'Najnovšie VPN pripojenia s týmto účtom.',
    'The number of currently connected VPN clients, and the maximum possible number of connected VPN clients based on available IP-space for this profile.' => 'Počet aktuálne pripojených VPN klientov a maximálny možný počet pripojených VPN klientov na základe dostupného IP priestoru pre tento profil.',
    'The number of unique guest users connecting to the VPN service in the last week' => 'Počet jedinečných externých používateľov pripojených k VPN službe počas posledného týždňa',
    'The number of unique users connecting to the VPN service in the last week' => 'Počet jedinečných používateľov pripojených k VPN službe počas posledného týždňa',
    'The table below shows the per profile VPN usage over the last week.' => 'Tabuľka nižšie zobrazuje využitie VPN profilov za posledný týždeň.',
    'There are no results matching your criteria.' => 'Neexistujú žiadne výsledky zodpovedajúce vašim kritériám.',
    'This server uses an external authentication source. Deleting the account data will not prevent the user from authenticating (again)!' => 'Tento server používa externý autentizačný zdroj. Odstránenie údajov o účte nezabráni používateľovi v overení (znovu)!',
    'This user does not have any active configurations.' => 'Tento používateľ nemá žiadne aktívne konfigurácie.',
    //'This user does not have any authorized applications.' => '',
    'This user does not have any connections.' => 'Tento používateľ nemá žiadne pripojenia.',
    'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'Ak chcete zabrániť zákerným aplikáciám vo vašom mene tajne vytvárať VPN pripojenia, musíte najskôr túto aplikáciu explicitne schváliť.',
    'Use the WireGuard app on your mobile device to scan this QR code.' => 'Použite aplikáciu WireGuard na svojom mobilnom zariadení na oskenovanie tohto QR kódu.',
    'User ID' => 'Používateľské ID',
    'Username' => 'Používateľské meno',
    'Users' => 'Používatelia',
    'VPN Portal' => 'VPN portál',
    'Version' => 'Verzia',
    'Welcome to this VPN service!' => 'Vitajte v tejto VPN službe!',
    'Why is this necessary?' => 'Prečo je toto nevyhnutné?',
    'WireGuard' => 'WireGuard',
    //'WireGuard (TCP)' => '',
    //'WireGuard (UDP)' => '',
    'WireGuard Configuration' => 'WireGuard konfigurácia',
    'You can download the detailed VPN usage statistics below.' => 'Podrobné štatistiky používania VPN si môžete stiahnuť nižšie.',
    'You cannot manage your own user account.' => 'Nemôžete spravovať svoj vlastný používateľský účet.',
    'You have reached the maximum number of allowed active VPN configurations. Delete some first.' => 'Dosiahli ste maximálny počet povolených aktívnych VPN konfigurácií. Najskôr niektoré zmažte.',
    'Your account does not have access to any VPN profile.' => 'Váš účet nemá prístup k žiadnemu VPN profilu.',
    'Your new configuration will expire on %expiryDate%. Come back here to obtain a new configuration after expiry!' => 'Vaša nová konfigurácia vyprší %expiryDate%. Po vypršaní príďte sem pre získanie novej konfigurácie!',
];
